@@ -8,7 +8,11 @@ class EmailAuthBackend(ModelBackend):
 
     """Allow users to log in with their email address"""
 
-    def authenticate(self, email=None, password=None):
+    def authenticate(self, email=None, password=None, **kwargs):
+        # Some authenticators expect to authenticate by 'username'
+        if email is None:
+            email = kwargs.get('username')
+
         try:
             user = get_user(email)
             if user.check_password(password):
